/*  vdagentd.c vdagentd xorg.conf writing code

    Copyright 2011, 2012 Red Hat, Inc.

    Red Hat Authors:
    Hans de Goede <hdegoede@redhat.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or   
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of 
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the  
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __VDAGENTD_XORG_CONF_H
#define __VDAGENTD_XORG_CONF_H

#include <stdio.h>
#include <spice/vd_agent.h>

void vdagentd_write_xorg_conf(VDAgentMonitorsConfig *monitor_conf);

#endif
